<?php
/**
 * Elementor PVFW_iFrame_SC Widget.
 *
 * Elementor widget that embeds a pdf viewer into the page
 *
 * @since 1.0.0
 */
class Elementor_PVFW_iFrame_SC_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve PVFW_Link_SC widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'pvfw_iframe_shortcode';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve PVFW_Link_SC widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'PDF Viewer iFrame', 'elementor-pvfw' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve PVFW_Link_SC widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-file-pdf';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the PVFW_Link_SC widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'media' ];
	}

	/**
	 * Register PVFW_Link_SC widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'basic_section',
			[
				'label' => esc_html__( 'Basic Information', 'elementor-pvfw' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'file_url',
			[
				'label' => esc_html__( 'File Url', 'elementor-pvfw' ),
				'type' => 'file-select',
				'input_type' => 'text',
				'placeholder' => esc_html__( 'URL to PDF File', 'elementor-pvfw' ),
				'description' => esc_html__( 'Upload or Select the PDF File', 'elementor-pvfw' ),
			]
		);

		$this->add_control(
			'width',
			[
				'label' => esc_html__( 'Width', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'input_type' => 'text',
				'placeholder' => esc_html__( 'Ex. 100%', 'elementor-pvfw' ),
				'description' => esc_html__( 'Width of the Viewer', 'elementor-pvfw' ),
				'default'	=> '100%',
			]
		);

		$this->add_control(
			'height',
			[
				'label' => esc_html__( 'Height', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'input_type' => 'text',
				'placeholder' => esc_html__( 'Ex. 800', 'elementor-pvfw' ),
				'description' => esc_html__( 'Height of the Viewer', 'elementor-pvfw' ),
				'default'	=> '800',
			]
		);

		$this->add_control(
			'default_scroll',
			[
				'label' => esc_html__( 'Default Scroll', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'0' 	=> esc_html__( 'Vertical', 'elementor-pvfw' ),
					'1' 	=> esc_html__( 'Horizontal', 'elementor-pvfw' ),
					'2' 	=> esc_html__( 'Wrapped', 'elementor-pvfw' ),
					'3' 	=> esc_html__( 'Flip', 'elementor-pvfw' ),
				],
				'default' => '0',
				'description' => esc_html__( 'Select Default Scroll Mode', 'elementor-pvfw' ),
			]
		);

		$this->add_control(
			'default_spread',
			[
				'label' => esc_html__( 'Default Spread', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'0' 	=> esc_html__( 'No Spreads', 'elementor-pvfw' ),
					'1' 	=> esc_html__( 'Odd Spreads', 'elementor-pvfw' ),
					'2' 	=> esc_html__( 'Even Spreads', 'elementor-pvfw' ),
				],
				'default' => '0',
				'description' => esc_html__( 'Select Default Spread Mode, Select Even Spread if you want to use FlipBook Style.', 'elementor-pvfw' ),
			]
		);

		$this->add_control(
			'default_zoom',
			[
				'label' => esc_html__( 'Default Zoom', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'auto' 			=> esc_html__( 'Auto', 'elementor-pvfw' ),
					'page-fit' 		=> esc_html__( 'Page Fit', 'elementor-pvfw' ),
					'page-width' 	=> esc_html__( 'Page Width', 'elementor-pvfw' ),
					'page-height' 	=> esc_html__( 'Page Height', 'elementor-pvfw' ),
					'75' 			=> esc_html__( '75%', 'elementor-pvfw' ),
					'100' 			=> esc_html__( '100%', 'elementor-pvfw' ),
					'150' 			=> esc_html__( '150%', 'elementor-pvfw' ),
					'200' 			=> esc_html__( '200%', 'elementor-pvfw' ),
				],
				'default' => 'auto',
				'description' => esc_html__( 'Select Default Zoom Level', 'elementor-pvfw' ),
			]
		);

		$this->add_control(
			'page_mode',
			[
				'label' => esc_html__( 'Default Page Mode', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'none' 			=> esc_html__( 'Default', 'elementor-pvfw' ),
					'thumbs' 		=> esc_html__( 'Thumbnails', 'elementor-pvfw' ),
					'bookmarks' 	=> esc_html__( 'Bookmarks', 'elementor-pvfw' ),
					'attachments' 	=> esc_html__( 'Attachments', 'elementor-pvfw' ),
				],
				'default' 	=> 'none',
				'description' => esc_html__( 'Select Default Page Mode', 'elementor-pvfw' ),
			]
		);

		$this->add_control(
			'page',
			[
				'label' 		=> esc_html__( 'Jump to Page', 'elementor-pvfw' ),
				'type' 			=> \Elementor\Controls_Manager::TEXT,
				'placeholder'	=> esc_html__('Ex. 2', 'elementor-pvfw'),
				'default' 		=> 'true',
				'description' 	=> esc_html__( 'Show/Hide Download Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$this->add_control(
			'iframe_title',
			[
				'label' => esc_html__( 'iFrame Title', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'input_type' => 'text',
				'placeholder' => esc_html__( 'Ex. PDF Viewer', 'elementor-pvfw' ),
				'description' => esc_html__( 'Title of the iFrame', 'elementor-pvfw' ),
			]
		);

		$get_current_spread_setting = get_option( 'hide_spread' );
		if( $get_current_spread_setting == "on"){
			$get_current_spread_setting = 'false';
		} else {
			$get_current_spread_setting = 'true';
		}
		$this->add_control(
			'language',
			[
				'label' => esc_html__( 'Language', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'en-US'	=>	 esc_html__( 'en-US', 'elementor-pvfw' ),
					'ach'	=>	 esc_html__( 'ach', 'elementor-pvfw' ),
					'af'	=>	 esc_html__( 'af', 'elementor-pvfw' ),
					'ak'	=>	 esc_html__( 'ak', 'elementor-pvfw' ),
					'an'	=>	 esc_html__( 'an', 'elementor-pvfw' ),
					'ar'	=>	 esc_html__( 'ar', 'elementor-pvfw' ),
					'as'	=>	 esc_html__( 'as', 'elementor-pvfw' ),
					'ast'	=>	 esc_html__( 'ast', 'elementor-pvfw' ),
					'az'	=>	 esc_html__( 'az', 'elementor-pvfw' ),
					'be'	=>	 esc_html__( 'be', 'elementor-pvfw' ),
					'bg'	=>	 esc_html__( 'bg', 'elementor-pvfw' ),
					'bn-BD'	=>	 esc_html__( 'bn-BD', 'elementor-pvfw' ),
					'bn-IN'	=>	 esc_html__( 'bn-IN', 'elementor-pvfw' ),
					'br'	=>	 esc_html__( 'br', 'elementor-pvfw' ),
					'bs'	=>	 esc_html__( 'bs', 'elementor-pvfw' ),
					'ca'	=>	 esc_html__( 'ca', 'elementor-pvfw' ),
					'cs'	=>	 esc_html__( 'cs', 'elementor-pvfw' ),
					'csb'	=>	 esc_html__( 'csb', 'elementor-pvfw' ),
					'cy'	=>	 esc_html__( 'cy', 'elementor-pvfw' ),
					'da'	=>	 esc_html__( 'da', 'elementor-pvfw' ),
					'de'	=>	 esc_html__( 'de', 'elementor-pvfw' ),
					'el'	=>	 esc_html__( 'el', 'elementor-pvfw' ),
					'en-GB'	=>	 esc_html__( 'en-GB', 'elementor-pvfw' ),
					'en-ZA'	=>	 esc_html__( 'en-ZA', 'elementor-pvfw' ),
					'eo'	=>	 esc_html__( 'eo', 'elementor-pvfw' ),
					'es-AR'	=>	 esc_html__( 'es-AR', 'elementor-pvfw' ),
					'es-CL'	=>	 esc_html__( 'es-CL', 'elementor-pvfw' ),
					'es-ES'	=>	 esc_html__( 'es-ES', 'elementor-pvfw' ),
					'es-MX'	=>	 esc_html__( 'es-MX', 'elementor-pvfw' ),
					'et'	=>	 esc_html__( 'et', 'elementor-pvfw' ),
					'eu'	=>	 esc_html__( 'eu', 'elementor-pvfw' ),
					'fa'	=>	 esc_html__( 'fa', 'elementor-pvfw' ),
					'ff'	=>	 esc_html__( 'ff', 'elementor-pvfw' ),
					'fi'	=>	 esc_html__( 'fi', 'elementor-pvfw' ),
					'fr'	=>	 esc_html__( 'fr', 'elementor-pvfw' ),
					'fy-NL'	=>	 esc_html__( 'fy-NL', 'elementor-pvfw' ),
					'ga-IE'	=>	 esc_html__( 'ga-IE', 'elementor-pvfw' ),
					'gd'	=>	 esc_html__( 'gd', 'elementor-pvfw' ),
					'gl'	=>	 esc_html__( 'gl', 'elementor-pvfw' ),
					'gu-IN'	=>	 esc_html__( 'gu-IN', 'elementor-pvfw' ),
					'he'	=>	 esc_html__( 'he', 'elementor-pvfw' ),
					'hi-IN'	=>	 esc_html__( 'hi-IN', 'elementor-pvfw' ),
					'hr'	=>	 esc_html__( 'hr', 'elementor-pvfw' ),
					'hu'	=>	 esc_html__( 'hu', 'elementor-pvfw' ),
					'hy-AM'	=>	 esc_html__( 'hy-AM', 'elementor-pvfw' ),
					'id'	=>	 esc_html__( 'id', 'elementor-pvfw' ),
					'is'	=>	 esc_html__( 'is', 'elementor-pvfw' ),
					'it'	=>	 esc_html__( 'it', 'elementor-pvfw' ),
					'ja'	=>	 esc_html__( 'ja', 'elementor-pvfw' ),
					'ka'	=>	 esc_html__( 'ka', 'elementor-pvfw' ),
					'kk'	=>	 esc_html__( 'kk', 'elementor-pvfw' ),
					'km'	=>	 esc_html__( 'km', 'elementor-pvfw' ),
					'kn'	=>	 esc_html__( 'kn', 'elementor-pvfw' ),
					'ko'	=>	 esc_html__( 'ko', 'elementor-pvfw' ),
					'ku'	=>	 esc_html__( 'ku', 'elementor-pvfw' ),
					'lg'	=>	 esc_html__( 'lg', 'elementor-pvfw' ),
					'lij'	=>	 esc_html__( 'lij', 'elementor-pvfw' ),
					'lt'	=>	 esc_html__( 'lt', 'elementor-pvfw' ),
					'lv'	=>	 esc_html__( 'lv', 'elementor-pvfw' ),
					'mai'	=>	 esc_html__( 'mai', 'elementor-pvfw' ),
					'mk'	=>	 esc_html__( 'mk', 'elementor-pvfw' ),
					'ml'	=>	 esc_html__( 'ml', 'elementor-pvfw' ),
					'mn'	=>	 esc_html__( 'mn', 'elementor-pvfw' ),
					'mr'	=>	 esc_html__( 'mr', 'elementor-pvfw' ),
					'ms'	=>	 esc_html__( 'ms', 'elementor-pvfw' ),
					'my'	=>	 esc_html__( 'my', 'elementor-pvfw' ),
					'nb-NO'	=>	 esc_html__( 'nb-NO', 'elementor-pvfw' ),
					'nl'	=>	 esc_html__( 'nl', 'elementor-pvfw' ),
					'nn-NO'	=>	 esc_html__( 'nn-NO', 'elementor-pvfw' ),
					'nso'	=>	 esc_html__( 'nso', 'elementor-pvfw' ),
					'oc'	=>	 esc_html__( 'oc', 'elementor-pvfw' ),
					'or'	=>	 esc_html__( 'or', 'elementor-pvfw' ),
					'pa-IN'	=>	 esc_html__( 'pa-IN', 'elementor-pvfw' ),
					'pl'	=>	 esc_html__( 'pl', 'elementor-pvfw' ),
					'pt-BR'	=>	 esc_html__( 'pt-BR', 'elementor-pvfw' ),
					'pt-PT'	=>	 esc_html__( 'pt-PT', 'elementor-pvfw' ),
					'rm'	=>	 esc_html__( 'rm', 'elementor-pvfw' ),
					'ro'	=>	 esc_html__( 'ro', 'elementor-pvfw' ),
					'ru'	=>	 esc_html__( 'ru', 'elementor-pvfw' ),
					'rw'	=>	 esc_html__( 'rw', 'elementor-pvfw' ),
					'sah'	=>	 esc_html__( 'sah', 'elementor-pvfw' ),
					'si'	=>	 esc_html__( 'si', 'elementor-pvfw' ),
					'sk'	=>	 esc_html__( 'sk', 'elementor-pvfw' ),
					'sl'	=>	 esc_html__( 'sl', 'elementor-pvfw' ),
					'son'	=>	 esc_html__( 'son', 'elementor-pvfw' ),
					'sq'	=>	 esc_html__( 'sq', 'elementor-pvfw' ),
					'sr'	=>	 esc_html__( 'sr', 'elementor-pvfw' ),
					'sv-SE'	=>	 esc_html__( 'sv-SE', 'elementor-pvfw' ),
					'sw'	=>	 esc_html__( 'sw', 'elementor-pvfw' ),
					'ta'	=>	 esc_html__( 'ta', 'elementor-pvfw' ),
					'ta-LK'	=>	 esc_html__( 'ta-LK', 'elementor-pvfw' ),
					'te'	=>	 esc_html__( 'te', 'elementor-pvfw' ),
					'th'	=>	 esc_html__( 'th', 'elementor-pvfw' ),
					'tl'	=>	 esc_html__( 'tl', 'elementor-pvfw' ),
					'tn'	=>	 esc_html__( 'tn', 'elementor-pvfw' ),
					'tr'	=>	 esc_html__( 'tr', 'elementor-pvfw' ),
					'uk'	=>	 esc_html__( 'uk', 'elementor-pvfw' ),
					'ur'	=>	 esc_html__( 'ur', 'elementor-pvfw' ),
					'vi'	=>	 esc_html__( 'vi', 'elementor-pvfw' ),
					'wo'	=>	 esc_html__( 'wo', 'elementor-pvfw' ),
					'xh'	=>	 esc_html__( 'xh', 'elementor-pvfw' ),
					'zh-CN'	=>	 esc_html__( 'zh-CN', 'elementor-pvfw' ),
					'zh-TW'	=>	 esc_html__( 'zh-TW', 'elementor-pvfw' ),
					'zu'	=>	 esc_html__( 'zu', 'elementor-pvfw' ),
				],
				'default' => 'en-US',
				'description' => esc_html__( 'Select Default Language', 'elementor-pvfw' ),
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'Toolbar Elements', 'elementor-pvfw' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$get_current_download_setting = get_option( 'hide_download' );
		if( $get_current_download_setting == "on"){
			$get_current_download_setting = 'false';
		} else {
			$get_current_download_setting = 'true';
		}
		$this->add_control(
			'download',
			[
				'label' => esc_html__( 'Download', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_download_setting,
				'description' => esc_html__( 'Show/Hide Download Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_print_setting = get_option( 'hide_print' );
		if( $get_current_print_setting == "on"){
			$get_current_print_setting = 'false';
		} else {
			$get_current_print_setting = 'true';
		}
		$this->add_control(
			'print',
			[
				'label' => esc_html__( 'Print', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_print_setting,
				'description' => esc_html__( 'Show/Hide Print Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_share_setting = get_option( 'hide_share' );
		if( $get_current_share_setting == "on"){
			$get_current_share_setting = 'false';
		} else {
			$get_current_share_setting = 'true';
		}
		$this->add_control(
			'share',
			[
				'label' => esc_html__( 'Share', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_share_setting,
				'description' => esc_html__( 'Show/Hide Share Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_fullscreen_setting = get_option( 'hide_fullscreen' );
		if( $get_current_fullscreen_setting == "on"){
			$get_current_fullscreen_setting = 'false';
		} else {
			$get_current_fullscreen_setting = 'true';
		}
		$this->add_control(
			'fullscreen',
			[
				'label' => esc_html__( 'FullScreen', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_fullscreen_setting,
				'description' => esc_html__( 'Show/Hide FullScreen Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_logo_setting = get_option( 'hide_logo' );
		if( $get_current_logo_setting == "on"){
			$get_current_logo_setting = 'false';
		} else {
			$get_current_logo_setting = 'true';
		}
		$this->add_control(
			'logo',
			[
				'label' => esc_html__( 'Logo', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_logo_setting,
				'description' => esc_html__( 'Show/Hide Logo Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_zoom_setting = get_option( 'hide_zoom' );
		if( $get_current_zoom_setting == "on"){
			$get_current_zoom_setting = 'false';
		} else {
			$get_current_zoom_setting = 'true';
		}
		$this->add_control(
			'zoom',
			[
				'label' => esc_html__( 'Zoom', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_zoom_setting,
				'description' => esc_html__( 'Show/Hide Zoom Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_open_setting = get_option( 'hide_open' );
		if( $get_current_open_setting == "on"){
			$get_current_open_setting = 'false';
		} else {
			$get_current_open_setting = 'true';
		}
		$this->add_control(
			'open',
			[
				'label' => esc_html__( 'Open', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_open_setting,
				'description' => esc_html__( 'Show/Hide Open Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_pagenav_setting = get_option( 'hide_pagenav' );
		if( $get_current_pagenav_setting == "on"){
			$get_current_pagenav_setting = 'false';
		} else {
			$get_current_pagenav_setting = 'true';
		}
		$this->add_control(
			'pagenav',
			[
				'label' => esc_html__( 'PageNav', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_pagenav_setting,
				'description' => esc_html__( 'Show/Hide PageNav Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_find_setting = get_option( 'hide_find' );
		if( $get_current_find_setting == "on"){
			$get_current_find_setting = 'false';
		} else {
			$get_current_find_setting = 'true';
		}
		$this->add_control(
			'find',
			[
				'label' => esc_html__( 'Find', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_find_setting,
				'description' => esc_html__( 'Show/Hide Find Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_current_view_setting = get_option( 'hide_current_view' );
		if( $get_current_current_view_setting == "on"){
			$get_current_current_view_setting = 'false';
		} else {
			$get_current_current_view_setting = 'true';
		}
		$this->add_control(
			'current_view',
			[
				'label' => esc_html__( 'Current View', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_current_view_setting,
				'description' => esc_html__( 'Show/Hide Current View Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_toggle_menu_setting = get_option( 'hide_toggle_menu' );
		if( $get_current_toggle_menu_setting == "on"){
			$get_current_toggle_menu_setting = 'false';
		} else {
			$get_current_toggle_menu_setting = 'true';
		}
		$this->add_control(
			'toggle_menu',
			[
				'label' => esc_html__( 'Toggle Menu (Right)', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_toggle_menu_setting,
				'description' => esc_html__( 'Show/Hide Toggle Menu (Right) Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_toggle_left_setting = get_option( 'hide_toggle_left' );
		if( $get_current_toggle_left_setting == "on"){
			$get_current_toggle_left_setting = 'false';
		} else {
			$get_current_toggle_left_setting = 'true';
		}
		$this->add_control(
			'toggle_left',
			[
				'label' => esc_html__( 'Toggle Menu (Left)', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_toggle_left_setting,
				'description' => esc_html__( 'Show/Hide Toggle Menu (Left) Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_rotate_setting = get_option( 'hide_rotate' );
		if( $get_current_rotate_setting == "on"){
			$get_current_rotate_setting = 'false';
		} else {
			$get_current_rotate_setting = 'true';
		}
		$this->add_control(
			'rotate',
			[
				'label' => esc_html__( 'Rotate', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_rotate_setting,
				'description' => esc_html__( 'Show/Hide Rotate Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_handtool_setting = get_option( 'hide_handtool' );
		if( $get_current_handtool_setting == "on"){
			$get_current_handtool_setting = 'false';
		} else {
			$get_current_handtool_setting = 'true';
		}
		$this->add_control(
			'handtool',
			[
				'label' => esc_html__( 'HandTool', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_handtool_setting,
				'description' => esc_html__( 'Show/Hide HandTool Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_doc_prop_setting = get_option( 'hide_doc_prop' );
		if( $get_current_doc_prop_setting == "on"){
			$get_current_doc_prop_setting = 'false';
		} else {
			$get_current_doc_prop_setting = 'true';
		}
		$this->add_control(
			'doc_prop',
			[
				'label' => esc_html__( 'Document Properties', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_doc_prop_setting,
				'description' => esc_html__( 'Show/Hide Document Properties Toolbar Element.', 'elementor-pvfw' ),
			]
		);


		$get_current_scroll_setting = get_option( 'hide_scroll' );
		if( $get_current_scroll_setting == "on"){
			$get_current_scroll_setting = 'false';
		} else {
			$get_current_scroll_setting = 'true';
		}
		$this->add_control(
			'scroll',
			[
				'label' => esc_html__( 'Scroll', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_scroll_setting,
				'description' => esc_html__( 'Show/Hide Scroll Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$get_current_spread_setting = get_option( 'hide_spread' );
		if( $get_current_spread_setting == "on"){
			$get_current_spread_setting = 'false';
		} else {
			$get_current_spread_setting = 'true';
		}
		$this->add_control(
			'spread',
			[
				'label' => esc_html__( 'Spread', 'elementor-pvfw' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'true' => esc_html__( 'Show', 'elementor-pvfw' ),
					'false' => esc_html__( 'Hide', 'elementor-pvfw' ),
				],
				'default' => $get_current_spread_setting,
				'description' => esc_html__( 'Show/Hide Spread Toolbar Element.', 'elementor-pvfw' ),
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Render PVFW_iFrame_SC widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();

		if( empty( $settings['file_url'] ) ){
			echo '[tnc-pdf-viewer-iframe file="' . $settings['file_url'] . '" width="' . $settings['width'] . '" height="' . $settings['height'] . '" download="' . $settings['download'] . '" print="' . $settings['print'] . '" fullscreen="' . $settings['fullscreen'] . '" share="' . $settings['share'] . '" zoom="' . $settings['zoom'] . '" open="' . $settings['open'] . '" pagenav="' . $settings['pagenav'] . '" logo="' . $settings['logo'] . '" find="' . $settings['find'] . '" current_view="' . $settings['current_view'] . '" rotate="' . $settings['rotate'] . '" handtool="' . $settings['handtool'] . '" doc_prop="' . $settings['doc_prop'] . '" toggle_menu="' . $settings['toggle_menu'] . '" toggle_left="' . $settings['toggle_left'] . '" scroll="' . $settings['scroll'] . '" spread="' . $settings['spread'] . '" default_scroll="' . $settings['default_scroll'] . '" default_spread="' . $settings['default_spread'] . '" language="' . $settings['language'] . '" iframe_title="' . $settings['iframe_title'] . '" page="' . $settings['page'] . '" default_zoom="' . $settings['default_zoom'] . '" pagemode="' . $settings['page_mode'] . '"]';
		} else {
			echo do_shortcode('[tnc-pdf-viewer-iframe file="' . $settings['file_url'] . '" width="' . $settings['width'] . '" height="' . $settings['height'] . '" download="' . $settings['download'] . '" print="' . $settings['print'] . '" fullscreen="' . $settings['fullscreen'] . '" share="' . $settings['share'] . '" zoom="' . $settings['zoom'] . '" open="' . $settings['open'] . '" pagenav="' . $settings['pagenav'] . '" logo="' . $settings['logo'] . '" find="' . $settings['find'] . '" current_view="' . $settings['current_view'] . '" rotate="' . $settings['rotate'] . '" handtool="' . $settings['handtool'] . '" doc_prop="' . $settings['doc_prop'] . '" toggle_menu="' . $settings['toggle_menu'] . '" toggle_left="' . $settings['toggle_left'] . '" scroll="' . $settings['scroll'] . '" spread="' . $settings['spread'] . '" default_scroll="' . $settings['default_scroll'] . '" default_spread="' . $settings['default_spread'] . '" language="' . $settings['language'] . '" iframe_title="' . $settings['iframe_title'] . '" page="' . $settings['page'] . '" default_zoom="' . $settings['default_zoom'] . '" pagemode="' . $settings['page_mode'] . '"]');
		}
	}
} 